==> software:readingrecord-2013-02-25.466.tar.gz: ReadingRecord-2013-02-25.466/database_templates/template_db.sql <==
-- Copyright (C) 2012, 2013 by the Free Software Foundation, Inc. http://www.fsf.org/

-- This file is part of ReadingRecord.
-- Created & developed by Eric Sisler <lbylnxgek@gmail.com>

-- ReadingRecord is free software: you can redistribute it and/or modify
-- it under the terms of the GNU Affero General Public License as published by
-- the Free Software Foundation, either version 3 of the License, or
-- (at your option) any later version.

-- ReadingRecord is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU Affero General Public License for more details.

-- You should have received a copy of the GNU Affero General Public License
-- along with ReadingRecord. If not, see http://www.gnu.org/licenses/.

-- Subversion: $Id: template_db.sql 465 2013-02-25 22:09:04Z esisler $

-- phpMyAdmin SQL Dump
-- version 2.11.11.3
-- http://www.phpmyadmin.net
--
-- Host: localhost
-- Generation Time: Feb 25, 2013 at 02:57 PM
-- Server version: 5.0.95
-- PHP Version: 5.1.6

SET SQL_MODE="NO_AUTO_VALUE_ON_ZERO";


/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8 */;

--
-- Database: `template_1`
--
CREATE DATABASE `template_1` DEFAULT CHARACTER SET latin1 COLLATE latin1_swedish_ci;
USE `template_1`;

-- --------------------------------------------------------

--
-- Table structure for table `age`
--

CREATE TABLE IF NOT EXISTS `age` (
  `age_id` tinyint(3) unsigned NOT NULL auto_increment,
  `desc` varchar(50) NOT NULL,
  `sort_ord` smallint(5) unsigned NOT NULL,
  PRIMARY KEY  (`age_id`),
  UNIQUE KEY `sort_ord` (`sort_ord`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1 AUTO_INCREMENT=1 ;

--
-- Dumping data for table `age`
--


-- --------------------------------------------------------

--
-- Table structure for table `city`
--

CREATE TABLE IF NOT EXISTS `city` (
  `city_id` tinyint(3) unsigned NOT NULL auto_increment,
  `desc` varchar(50) NOT NULL,
  `sort_ord` smallint(5) unsigned NOT NULL,
  PRIMARY KEY  (`city_id`),
  UNIQUE KEY `sort_ord` (`sort_ord`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1 AUTO_INCREMENT=1 ;

--
-- Dumping data for table `city`
--


-- --------------------------------------------------------

--
-- Table structure for table `grade`
--

CREATE TABLE IF NOT EXISTS `grade` (
  `grade_id` tinyint(3) unsigned NOT NULL auto_increment,
  `desc` varchar(50) NOT NULL,
  `sort_ord` smallint(5) unsigned NOT NULL,
  PRIMARY KEY  (`grade_id`),
  UNIQUE KEY `sort_ord` (`sort_ord`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1 AUTO_INCREMENT=1 ;

--
-- Dumping data for table `grade`
--


-- --------------------------------------------------------

--
-- Table structure for table `level`
--

CREATE TABLE IF NOT EXISTS `level` (
  `level_id` tinyint(3) unsigned NOT NULL auto_increment,
  `desc` varchar(50) NOT NULL,
  `info` varchar(75) NOT NULL,
  PRIMARY KEY  (`level_id`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1 AUTO_INCREMENT=1 ;

--
-- Dumping data for table `level`
--


-- --------------------------------------------------------

--
-- Table structure for table `library`
--

CREATE TABLE IF NOT EXISTS `library` (
  `library_id` tinyint(3) unsigned NOT NULL auto_increment,
  `desc` varchar(50) NOT NULL,
  `sort_ord` smallint(5) unsigned NOT NULL,
  PRIMARY KEY  (`library_id`),
  UNIQUE KEY `sort_ord` (`sort_ord`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1 AUTO_INCREMENT=1 ;

--
-- Dumping data for table `library`
--


-- --------------------------------------------------------

--
-- Table structure for table `reader`
--

CREATE TABLE IF NOT EXISTS `reader` (
  `reader_id` smallint(5) unsigned NOT NULL auto_increment,
  `date_added` timestamp NOT NULL default CURRENT_TIMESTAMP,
  `date_updated` datetime default NULL,
  `reg_ip` varchar(15) NOT NULL,
  `reg_host` varchar(50) NOT NULL,
  `library_id` tinyint(3) unsigned default NULL,
  `first_name` varchar(50) NOT NULL,
  `last_name` varchar(50) NOT NULL,
  `phone` varchar(12) NOT NULL,
  `age_id` tinyint(3) unsigned default NULL,
  `city_id` tinyint(3) unsigned default NULL,
  `zipcode_id` tinyint(3) unsigned default NULL,
  `email` varchar(50) default NULL,
  `barcode` varchar(50) default NULL,
  `grade_id` tinyint(3) unsigned default NULL,
  `school_id` tinyint(3) unsigned default NULL,
  `date_validated` datetime default '0000-00-00 00:00:00',
  `notes` varchar(255) default NULL,
  PRIMARY KEY  (`reader_id`),
  UNIQUE KEY `reader_unique` (`first_name`,`last_name`,`phone`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1 AUTO_INCREMENT=1 ;

--
-- Dumping data for table `reader`
--


-- --------------------------------------------------------

--
-- Table structure for table `record`
--

CREATE TABLE IF NOT EXISTS `record` (
  `record_id` mediumint(8) unsigned NOT NULL auto_increment,
  `reader_id` smallint(5) unsigned NOT NULL,
  `level_id` tinyint(3) unsigned NOT NULL,
  `date_completed` timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (`record_id`),
  UNIQUE KEY `record_unique` (`reader_id`,`level_id`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1 AUTO_INCREMENT=1 ;

--
-- Dumping data for table `record`
--


-- --------------------------------------------------------

--
-- Table structure for table `school`
--

CREATE TABLE IF NOT EXISTS `school` (
  `school_id` tinyint(3) unsigned NOT NULL auto_increment,
  `desc` varchar(50) NOT NULL,
  `sort_ord` smallint(5) unsigned NOT NULL,
  PRIMARY KEY  (`school_id`),
  UNIQUE KEY `sort_ord` (`sort_ord`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1 AUTO_INCREMENT=1 ;

--
-- Dumping data for table `school`
--


-- --------------------------------------------------------

--
-- Table structure for table `zipcode`
--

CREATE TABLE IF NOT EXISTS `zipcode` (
  `zipcode_id` tinyint(3) unsigned NOT NULL auto_increment,
  `desc` varchar(50) NOT NULL,
  `sort_ord` smallint(5) unsigned NOT NULL,
  PRIMARY KEY  (`zipcode_id`),
  UNIQUE KEY `sort_ord` (`sort_ord`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1 AUTO_INCREMENT=1 ;

--
-- Dumping data for table `zipcode`
--

--
-- Database: `template_config`
--
CREATE DATABASE `template_config` DEFAULT CHARACTER SET latin1 COLLATE latin1_swedish_ci;
USE `template_config`;

-- --------------------------------------------------------

--
-- Table structure for table `global`
--

CREATE TABLE IF NOT EXISTS `global` (
  `globalId` tinyint(3) unsigned NOT NULL,
  `indexStart` varchar(10) NOT NULL,
  `indexEnd` varchar(10) NOT NULL,
  `pageTitle` varchar(75) NOT NULL,
  `libraryName` varchar(50) NOT NULL,
  `hostDateOffset` varchar(50) NOT NULL default '0',
  `imageDir` varchar(50) NOT NULL,
  `bodyColor` varchar(50) NOT NULL,
  `hrOpts` varchar(50) NOT NULL,
  `allowDups` tinyint(1) unsigned NOT NULL default '1',
  `enable1` tinyint(1) unsigned NOT NULL,
  `enable2` tinyint(1) unsigned NOT NULL,
  `enable3` tinyint(1) unsigned NOT NULL,
  `enable4` tinyint(1) unsigned NOT NULL,
  `enable5` tinyint(1) unsigned NOT NULL,
  `enable6` tinyint(1) unsigned NOT NULL,
  `db1` varchar(50) NOT NULL,
  `db2` varchar(50) NOT NULL,
  `db3` varchar(50) NOT NULL,
  `db4` varchar(50) NOT NULL,
  `db5` varchar(50) NOT NULL,
  `db6` varchar(50) NOT NULL,
  PRIMARY KEY  (`globalId`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

--
-- Dumping data for table `global`
--

INSERT INTO `global` (`globalId`, `indexStart`, `indexEnd`, `pageTitle`, `libraryName`, `hostDateOffset`, `imageDir`, `bodyColor`, `hrOpts`, `allowDups`, `enable1`, `enable2`, `enable3`, `enable4`, `enable5`, `enable6`, `db1`, `db2`, `db3`, `db4`, `db5`, `db6`) VALUES
(1, '2013-01-01', '2013-12-31', 'ReadingRecord - TEMPLATE', 'TEMPLATE LIBRARY', '0', 'TEMPLATE.readingrecord.org', 'bgcolor="#D8D8BF"', 'width="90%" color="#ffbb00"', 1, 0, 0, 0, 0, 0, 0, 'TEMPLATE_1', 'TEMPLATE_2', 'TEMPLATE_3', 'TEMPLATE_4', 'TEMPLATE_5', 'TEMPLATE_6');

-- --------------------------------------------------------

--
-- Table structure for table `login`
--

CREATE TABLE IF NOT EXISTS `login` (
  `login_id` tinyint(3) unsigned NOT NULL auto_increment,
  `user_name` varchar(20) NOT NULL,
  `password` varchar(20) NOT NULL,
  `real_name` varchar(30) NOT NULL,
  `reports_access` tinyint(1) NOT NULL,
  PRIMARY KEY  (`login_id`),
  UNIQUE KEY `login` (`user_name`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1 AUTO_INCREMENT=1 ;

--
-- Dumping data for table `login`
--


-- --------------------------------------------------------

--
-- Table structure for table `program`
--

CREATE TABLE IF NOT EXISTS `program` (
  `progId` tinyint(3) unsigned NOT NULL,
  `regStart` varchar(10) NOT NULL,
  `regEnd` varchar(10) NOT NULL,
  `altURL` varchar(50) NOT NULL,
  `longPgrmName` varchar(75) NOT NULL,
  `shortPgrmName` varchar(50) NOT NULL,
  `pgrmMssg` varchar(50) NOT NULL,
  `pgrmInfo` mediumtext,
  `useLibrary` tinyint(1) unsigned NOT NULL,
  `usePersonalHeader` tinyint(1) unsigned NOT NULL,
  `phoneDigits` varchar(2) NOT NULL,
  `phoneError` varchar(100) default NULL,
  `phoneAreaCode` varchar(4) default NULL,
  `useAge` tinyint(1) unsigned NOT NULL,
  `useCity` tinyint(1) unsigned NOT NULL,
  `useZipcode` tinyint(3) unsigned NOT NULL,
  `useEmail` tinyint(1) unsigned NOT NULL,
  `requireEmail` tinyint(1) unsigned NOT NULL,
  `useBarcode` tinyint(1) unsigned NOT NULL,
  `requireBarcode` tinyint(1) unsigned NOT NULL,
  `useSchoolHeader` tinyint(1) unsigned NOT NULL,
  `useGrade` tinyint(1) unsigned NOT NULL,
  `gradeLabel` varchar(50) default NULL,
  `useSchool` tinyint(1) unsigned NOT NULL,
  `schoolLabel` varchar(50) default NULL,
  `regSuccessMssg` mediumtext,
  PRIMARY KEY  (`progId`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

--
-- Dumping data for table `program`
--

INSERT INTO `program` (`progId`, `regStart`, `regEnd`, `altURL`, `longPgrmName`, `shortPgrmName`, `pgrmMssg`, `pgrmInfo`, `useLibrary`, `usePersonalHeader`, `phoneDigits`, `phoneError`, `phoneAreaCode`, `useAge`, `useCity`, `useZipcode`, `useEmail`, `requireEmail`, `useBarcode`, `requireBarcode`, `useSchoolHeader`, `useGrade`, `gradeLabel`, `useSchool`, `schoolLabel`, `regSuccessMssg`) VALUES
(1, '2013-01-01', '2013-12-31', '', 'Program 1', 'prog1', 'mssg1', 'Info 1.', 0, 1, '10', 'Please use the format 123-456-7890.  No phone? Enter 000-000-0000.', '', 0, 0, 0, 0, 0, 0, 0, 0, 0, 'Last grade completed:', 0, 'Last school attended:', NULL),
(2, '2013-01-01', '2013-12-31', '', 'Program 2', 'prog2', 'mssg2', 'Info 2.', 0, 1, '10', 'Please use the format 123-456-7890.  No phone? Enter 000-000-0000.', '', 0, 0, 0, 0, 0, 0, 0, 0, 0, 'Last grade completed:', 0, 'Last school attended:', NULL),
(3, '2013-01-01', '2013-12-31', '', 'Program 3', 'prog3', 'mssg3', 'Info 3.', 0, 1, '10', 'Please use the format 123-456-7890.  No phone? Enter 000-000-0000.', '', 0, 0, 0, 0, 0, 0, 0, 0, 0, 'Last grade completed:', 0, 'Last school attended:', NULL),
(4, '2013-01-01', '2013-12-31', '', 'Program 4', 'prog4', 'mssg4', 'Info 4.', 0, 1, '10', 'Please use the format 123-456-7890.  No phone? Enter 000-000-0000.', '', 0, 0, 0, 0, 0, 0, 0, 0, 0, 'Last grade completed:', 0, 'Last school attended:', NULL),
(5, '2013-01-01', '2013-12-31', '', 'Program 5', 'prog5', 'mssg5', 'Info 5.', 0, 1, '10', 'Please use the format 123-456-7890.  No phone? Enter 000-000-0000.', '', 0, 0, 0, 0, 0, 0, 0, 0, 0, 'Last grade completed:', 0, 'Last school attended:', NULL),
(6, '2013-01-01', '2013-12-31', '', 'Program 6', 'prog6', 'mssg6', 'Info 6.', 0, 1, '10', 'Please use the format 123-456-7890.  No phone? Enter 000-000-0000.', '', 0, 0, 0, 0, 0, 0, 0, 0, 0, 'Last grade completed:', 0, 'Last school attended:', NULL);

==> software:readingrecord-2013-03-05.481.tar.gz: ReadingRecord-2013-03-05.481/database_templates/template_db.sql <==
-- Copyright (C) 2012, 2013 by the Free Software Foundation, Inc. http://www.fsf.org/

-- This file is part of ReadingRecord.
-- Created & developed by Eric Sisler <lbylnxgek@gmail.com>

-- ReadingRecord is free software: you can redistribute it and/or modify
-- it under the terms of the GNU Affero General Public License as published by
-- the Free Software Foundation, either version 3 of the License, or
-- (at your option) any later version.

-- ReadingRecord is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-- GNU Affero General Public License for more details.

-- You should have received a copy of the GNU Affero General Public License
-- along with ReadingRecord. If not, see http://www.gnu.org/licenses/.

-- Subversion: $Id: template_db.sql 481 2013-03-05 22:25:36Z esisler $

-- phpMyAdmin SQL Dump
-- version 2.11.11.3
-- http://www.phpmyadmin.net
--
-- Host: localhost
-- Generation Time: Mar 05, 2013 at 03:12 PM
-- Server version: 5.0.95
-- PHP Version: 5.1.6

SET SQL_MODE="NO_AUTO_VALUE_ON_ZERO";


/*!40101 SET @OLD_CHARACTER_SET_CLIENT=@@CHARACTER_SET_CLIENT */;
/*!40101 SET @OLD_CHARACTER_SET_RESULTS=@@CHARACTER_SET_RESULTS */;
/*!40101 SET @OLD_COLLATION_CONNECTION=@@COLLATION_CONNECTION */;
/*!40101 SET NAMES utf8 */;

--
-- Database: `template_1`
--
CREATE DATABASE `template_1` DEFAULT CHARACTER SET latin1 COLLATE latin1_swedish_ci;
USE `template_1`;

-- --------------------------------------------------------

--
-- Table structure for table `age`
--

CREATE TABLE IF NOT EXISTS `age` (
  `age_id` tinyint(3) unsigned NOT NULL auto_increment,
  `desc` varchar(20) NOT NULL,
  `sort_ord` smallint(5) unsigned NOT NULL,
  PRIMARY KEY  (`age_id`),
  UNIQUE KEY `sort_ord` (`sort_ord`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1 AUTO_INCREMENT=1 ;

--
-- Dumping data for table `age`
--


-- --------------------------------------------------------

--
-- Table structure for table `city`
--

CREATE TABLE IF NOT EXISTS `city` (
  `city_id` tinyint(3) unsigned NOT NULL auto_increment,
  `desc` varchar(30) NOT NULL,
  `sort_ord` smallint(5) unsigned NOT NULL,
  PRIMARY KEY  (`city_id`),
  UNIQUE KEY `sort_ord` (`sort_ord`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1 AUTO_INCREMENT=1 ;

--
-- Dumping data for table `city`
--


-- --------------------------------------------------------

--
-- Table structure for table `grade`
--

CREATE TABLE IF NOT EXISTS `grade` (
  `grade_id` tinyint(3) unsigned NOT NULL auto_increment,
  `desc` varchar(20) NOT NULL,
  `sort_ord` smallint(5) unsigned NOT NULL,
  PRIMARY KEY  (`grade_id`),
  UNIQUE KEY `sort_ord` (`sort_ord`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1 AUTO_INCREMENT=1 ;

--
-- Dumping data for table `grade`
--


-- --------------------------------------------------------

--
-- Table structure for table `level`
--

CREATE TABLE IF NOT EXISTS `level` (
  `level_id` tinyint(3) unsigned NOT NULL auto_increment,
  `desc` varchar(20) NOT NULL,
  `info` varchar(50) NOT NULL,
  PRIMARY KEY  (`level_id`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1 AUTO_INCREMENT=1 ;

--
-- Dumping data for table `level`
--


-- --------------------------------------------------------

--
-- Table structure for table `library`
--

CREATE TABLE IF NOT EXISTS `library` (
  `library_id` tinyint(3) unsigned NOT NULL auto_increment,
  `desc` varchar(30) NOT NULL,
  `sort_ord` smallint(5) unsigned NOT NULL,
  PRIMARY KEY  (`library_id`),
  UNIQUE KEY `sort_ord` (`sort_ord`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1 AUTO_INCREMENT=1 ;

--
-- Dumping data for table `library`
--


-- --------------------------------------------------------

--
-- Table structure for table `reader`
--

CREATE TABLE IF NOT EXISTS `reader` (
  `reader_id` smallint(5) unsigned NOT NULL auto_increment,
  `date_added` timestamp NOT NULL default CURRENT_TIMESTAMP,
  `date_updated` datetime default NULL,
  `reg_ip` varchar(15) NOT NULL,
  `reg_host` varchar(30) NOT NULL,
  `library_id` tinyint(3) unsigned default NULL,
  `first_name` varchar(50) NOT NULL,
  `last_name` varchar(50) NOT NULL,
  `phone` varchar(12) NOT NULL,
  `age_id` tinyint(3) unsigned default NULL,
  `city_id` tinyint(3) unsigned default NULL,
  `zipcode_id` tinyint(3) unsigned default NULL,
  `email` varchar(50) default NULL,
  `barcode` varchar(20) default NULL,
  `grade_id` tinyint(3) unsigned default NULL,
  `school_id` tinyint(3) unsigned default NULL,
  `date_validated` datetime default '0000-00-00 00:00:00',
  `notes` varchar(255) default NULL,
  PRIMARY KEY  (`reader_id`),
  UNIQUE KEY `reader_unique` (`first_name`,`last_name`,`phone`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1 AUTO_INCREMENT=1 ;

--
-- Dumping data for table `reader`
--


-- --------------------------------------------------------

--
-- Table structure for table `record`
--

CREATE TABLE IF NOT EXISTS `record` (
  `record_id` smallint(5) unsigned NOT NULL auto_increment,
  `reader_id` smallint(5) unsigned NOT NULL,
  `level_id` tinyint(3) unsigned NOT NULL,
  `date_completed` timestamp NOT NULL default CURRENT_TIMESTAMP,
  PRIMARY KEY  (`record_id`),
  UNIQUE KEY `reader_id` (`reader_id`,`level_id`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1 AUTO_INCREMENT=1 ;

--
-- Dumping data for table `record`
--


-- --------------------------------------------------------

--
-- Table structure for table `school`
--

CREATE TABLE IF NOT EXISTS `school` (
  `school_id` tinyint(3) unsigned NOT NULL auto_increment,
  `desc` varchar(40) NOT NULL,
  `sort_ord` smallint(5) unsigned NOT NULL,
  PRIMARY KEY  (`school_id`),
  UNIQUE KEY `sort_ord` (`sort_ord`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1 AUTO_INCREMENT=1 ;

--
-- Dumping data for table `school`
--


-- --------------------------------------------------------

--
-- Table structure for table `zipcode`
--

CREATE TABLE IF NOT EXISTS `zipcode` (
  `zipcode_id` tinyint(3) unsigned NOT NULL auto_increment,
  `desc` varchar(40) NOT NULL,
  `sort_ord` smallint(5) unsigned NOT NULL,
  PRIMARY KEY  (`zipcode_id`),
  UNIQUE KEY `sort_ord` (`sort_ord`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1 AUTO_INCREMENT=1 ;

--
-- Dumping data for table `zipcode`
--

--
-- Database: `template_config`
--
CREATE DATABASE `template_config` DEFAULT CHARACTER SET latin1 COLLATE latin1_swedish_ci;
USE `template_config`;

-- --------------------------------------------------------

--
-- Table structure for table `global`
--

CREATE TABLE IF NOT EXISTS `global` (
  `globalId` tinyint(3) unsigned NOT NULL,
  `indexStart` varchar(10) NOT NULL,
  `indexEnd` varchar(10) NOT NULL,
  `pageTitle` varchar(50) NOT NULL,
  `libraryName` varchar(50) NOT NULL,
  `hostDateOffset` varchar(50) NOT NULL default '0',
  `imageDir` varchar(50) NOT NULL,
  `bodyColor` varchar(50) NOT NULL,
  `hrOpts` varchar(50) NOT NULL,
  `allowDups` tinyint(1) unsigned NOT NULL default '1',
  `enable1` tinyint(1) unsigned NOT NULL,
  `enable2` tinyint(1) unsigned NOT NULL,
  `enable3` tinyint(1) unsigned NOT NULL,
  `enable4` tinyint(1) unsigned NOT NULL,
  `enable5` tinyint(1) unsigned NOT NULL,
  `enable6` tinyint(1) unsigned NOT NULL,
  `db1` varchar(50) NOT NULL,
  `db2` varchar(50) NOT NULL,
  `db3` varchar(50) NOT NULL,
  `db4` varchar(50) NOT NULL,
  `db5` varchar(50) NOT NULL,
  `db6` varchar(50) NOT NULL,
  PRIMARY KEY  (`globalId`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

--
-- Dumping data for table `global`
--

INSERT INTO `global` (`globalId`, `indexStart`, `indexEnd`, `pageTitle`, `libraryName`, `hostDateOffset`, `imageDir`, `bodyColor`, `hrOpts`, `allowDups`, `enable1`, `enable2`, `enable3`, `enable4`, `enable5`, `enable6`, `db1`, `db2`, `db3`, `db4`, `db5`, `db6`) VALUES
(1, '2013-01-01', '2013-12-31', 'ReadingRecord.org - TEMPLATE', 'TEMPLATE LIBRARY', '0', 'template.readingrecord.net', 'bgcolor="#D8D8BF"', 'width="90%" color="#ffbb00"', 0, 1, 1, 1, 1, 1, 1, 'dev_1', 'dev_2', 'dev_3', 'dev_4', 'dev_5', 'dev_6');

-- --------------------------------------------------------

--
-- Table structure for table `login`
--

CREATE TABLE IF NOT EXISTS `login` (
  `login_id` tinyint(3) unsigned NOT NULL auto_increment,
  `user_name` varchar(20) NOT NULL,
  `password` varchar(20) NOT NULL,
  `real_name` varchar(30) NOT NULL,
  `reports_access` tinyint(1) NOT NULL,
  PRIMARY KEY  (`login_id`),
  UNIQUE KEY `login` (`user_name`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1 AUTO_INCREMENT=1 ;

--
-- Dumping data for table `login`
--


-- --------------------------------------------------------

--
-- Table structure for table `program`
--

CREATE TABLE IF NOT EXISTS `program` (
  `progId` tinyint(3) unsigned NOT NULL,
  `regStart` varchar(10) NOT NULL,
  `regEnd` varchar(10) NOT NULL,
  `altURL` varchar(50) NOT NULL,
  `longPgrmName` varchar(50) NOT NULL,
  `shortPgrmName` varchar(50) NOT NULL,
  `pgrmMssg` varchar(50) NOT NULL,
  `pgrmInfo` mediumtext,
  `useLibrary` tinyint(1) unsigned NOT NULL,
  `libraryLabel` varchar(50) NOT NULL default 'Home Library:',
  `usePersonalHeader` tinyint(1) unsigned NOT NULL,
  `personalHeaderLabel` varchar(50) NOT NULL default 'Reader Info:',
  `firstNameLabel` varchar(50) NOT NULL default 'First Name:',
  `lastNameLabel` varchar(50) NOT NULL default 'Last Name:',
  `phoneDigits` varchar(2) NOT NULL,
  `phoneLabel` varchar(50) NOT NULL default 'Phone',
  `phoneError` varchar(100) default NULL,
  `phoneAreaCode` varchar(4) default NULL,
  `useAge` tinyint(1) unsigned NOT NULL,
  `ageLabel` varchar(50) NOT NULL default 'Age:',
  `useCity` tinyint(1) unsigned NOT NULL,
  `cityLabel` varchar(50) NOT NULL default 'City:',
  `useZipcode` tinyint(3) unsigned NOT NULL,
  `zipcodeLabel` varchar(50) NOT NULL default 'Zipcode:',
  `useEmail` tinyint(1) unsigned NOT NULL,
  `emailLabel` varchar(50) NOT NULL default 'E-mail address:',
  `requireEmail` tinyint(1) unsigned NOT NULL,
  `useBarcode` tinyint(1) unsigned NOT NULL,
  `barcodeLabel` varchar(50) NOT NULL default 'Library barcode:',
  `requireBarcode` tinyint(1) unsigned NOT NULL,
  `useSchoolHeader` tinyint(1) unsigned NOT NULL,
  `schoolHeaderLabel` varchar(50) NOT NULL default 'School Info:',
  `useGrade` tinyint(1) unsigned NOT NULL,
  `gradeLabel` varchar(50) default NULL,
  `useSchool` tinyint(1) unsigned NOT NULL,
  `schoolLabel` varchar(50) default NULL,
  `regSuccessMssg` mediumtext,
  PRIMARY KEY  (`progId`)
) ENGINE=MyISAM DEFAULT CHARSET=latin1;

--
-- Dumping data for table `program`
--

INSERT INTO `program` (`progId`, `regStart`, `regEnd`, `altURL`, `longPgrmName`, `shortPgrmName`, `pgrmMssg`, `pgrmInfo`, `useLibrary`, `libraryLabel`, `usePersonalHeader`, `personalHeaderLabel`, `firstNameLabel`, `lastNameLabel`, `phoneDigits`, `phoneLabel`, `phoneError`, `phoneAreaCode`, `useAge`, `ageLabel`, `useCity`, `cityLabel`, `useZipcode`, `zipcodeLabel`, `useEmail`, `emailLabel`, `requireEmail`, `useBarcode`, `barcodeLabel`, `requireBarcode`, `useSchoolHeader`, `schoolHeaderLabel`, `useGrade`, `gradeLabel`, `useSchool`, `schoolLabel`, `regSuccessMssg`) VALUES
(1, '2013-01-01', '2013-12-31', '', 'Program 1', 'prog1', 'mssg1', '<p>Info 1 paragraph 1.</p>\r\n\r\n<p>Info 1 paragraph 2.</p>\r\n\r\n<p><a href="http://www.google.com">Info 1 URL 1</a></p>', 1, 'Home Library:', 1, 'Reader Info:', 'First Name:', 'Last Name:', '10', 'Phone', 'Please use the format 123-456-7890.  No phone? Enter 000-000-0000.', '', 1, 'Age:', 1, 'City:', 1, 'Zipcode:', 1, 'E-Mail address:', 1, 1, 'Library barcode:', 1, 1, 'School Info:', 1, 'Last grade completed:', 1, 'Last school attended:', '<p>Program 1 success message.</p>'),
(2, '2013-01-01', '2013-12-31', '', 'Program 2', 'prog2', 'mssg2', 'Info 2.', 1, 'Home Library:', 1, 'Personal Info', 'First Name:', 'Last Name:', '10', 'Phone', 'Please use the format 123-456-7890.  No phone? Enter 000-000-0000.', '', 1, 'Age:', 1, 'City:', 1, 'Zipcode:', 1, 'E-mail address:', 0, 1, 'Library barcode:', 1, 1, 'School Info:', 1, 'Last grade completed:', 1, 'Last school attended:', '<p>Program 2 success message.</p>'),
(3, '2013-01-01', '2013-12-31', '', 'Program 3', 'prog3', 'mssg3', 'Info 3.', 1, 'Home Library:', 1, 'Personal Info', 'First Name:', 'Last Name:', '10', 'Phone', 'Please use the format 123-456-7890.  No phone? Enter 000-000-0000.', '', 0, 'Age:', 0, 'City:', 0, 'Zipcode:', 0, 'E-mail address:', 0, 0, 'Library barcode:', 0, 1, 'School Info:', 1, 'Last grade completed:', 1, 'Last school attended:', '<p>Program 3 success message.</p>'),
(4, '2013-01-01', '2013-12-31', '', 'Program 4', 'prog4', 'mssg4', 'Info 4.', 1, 'Home Library:', 1, 'Personal Info', 'First Name:', 'Last Name:', '10', 'Phone', 'Please use the format 123-456-7890.  No phone? Enter 000-000-0000.', NULL, 1, 'Age:', 1, 'City:', 1, 'Zipcode:', 0, 'E-mail address:', 0, 0, 'Library barcode:', 0, 1, 'School Info:', 1, 'Last grade completed:', 1, 'Last school attended:', '<p>Program 4 success message.</p>'),
(5, '2013-01-01', '2013-12-31', '', 'Program 5', 'prog5', 'mssg5', 'Info 5.', 1, 'Home Library:', 1, 'Personal Info', 'First Name:', 'Last Name:', '10', 'Phone', 'Please use the format 123-456-7890.  No phone? Enter 000-000-0000.', NULL, 1, 'Age:', 1, 'City:', 1, 'Zipcode:', 1, 'E-mail address:', 0, 1, 'Library barcode:', 0, 1, 'School Info:', 1, 'Last grade completed:', 1, 'Last school attended:', '<p>Program 5 success message.</p>'),
(6, '2013-01-01', '2013-12-31', '', 'Program 6', 'prog6', 'mssg6', 'Info 6.', 1, 'Home Library:', 1, 'Personal Info', 'First Name:', 'Last Name:', '10', 'Phone', 'Please use the format 123-456-7890.  No phone? Enter 000-000-0000.', NULL, 1, 'Age:', 1, 'City:', 1, 'Zipcode:', 1, 'E-mail address:', 0, 1, 'Library barcode:', 0, 1, 'School Info:', 1, 'Last grade completed:', 1, 'Last school attended:', '<p>Program 6 success message.</p>');
